Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var NoColors = Style{
Header: noOpANSI,
Comment: noOpANSI,
CommentHighlight: noOpANSI,
LogCategory: noOpANSI,
LogCachedName: noOpANSI,
Progress: noOpANSI,
LogArgument: noOpANSI,
LogResult: noOpANSI,
LogErrorReason: noOpANSI,
LogError: noOpANSI,
LogScope: noOpANSI,
ErrorHeader: noOpANSI,
LessRelevant: noOpANSI,
Highlight: noOpANSI,
ErrorWhat: noOpANSI,
TestSuccess: noOpANSI,
TestFailure: noOpANSI,
}
var WithColors = Style{ Header: aec.LightBlackF, Comment: aec.LightBlackF, CommentHighlight: aec.LightBlackF.With(aec.Bold), LogCategory: aec.LightBlueF, LogCachedName: aec.LightBlackF, Progress: aec.LightBlackF, LogArgument: aec.CyanF, LogResult: aec.BlueF, LogErrorReason: aec.BlueF, LogError: aec.RedF, LogScope: aec.Italic, ErrorHeader: aec.RedF.With(aec.Bold), LessRelevant: aec.Italic, Highlight: aec.Bold, ErrorWhat: aec.MagentaF, TestSuccess: aec.GreenF, TestFailure: aec.RedF, }
Functions ¶
Types ¶
type Applicable ¶
type Style ¶
type Style struct {
Header Applicable // Timestamps, etc.
Comment Applicable // Faded out, at the end of a line.
CommentHighlight Applicable
Progress Applicable // Inline content that is updated w/ progress.
ErrorHeader Applicable // Error prefixes.
LessRelevant Applicable // A passing detail, like the fact that a list is empty.
Highlight Applicable // Something we should highlight, usually in bold.
ErrorWhat Applicable // When formatting errors, the kind of error.
LogError Applicable // An error displayed in a log line.
LogCategory Applicable // Log line category.
LogCachedName Applicable // Names, when cached.
LogArgument Applicable // An argument to an invocation.
LogResult Applicable // The result of an invocation.
LogErrorReason Applicable // An expected error reason.
LogScope Applicable // Highlight of a package for which an invocation is being made.
TestSuccess Applicable // It says it on the tin.
TestFailure Applicable // Here too.
}
Click to show internal directories.
Click to hide internal directories.